<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>MX Package Installer</source>
        <translation>MX Instalátor softvéru </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Oblíbené aplikace</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Package</source>
        <translation>Balík</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="653"/>
        <location filename="../mainwindow.ui" line="975"/>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="619"/>
        <location filename="../mainwindow.ui" line="944"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Spravovat oblíbené balíky&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Šedé položky již byly nainstalovány.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Hlavní repozitář</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="889"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrovat balíky dle statusu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="567"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="892"/>
        <location filename="../mainwindow.ui" line="896"/>
        <location filename="../mainwindow.cpp" line="2188"/>
        <source>All packages</source>
        <translation>Všechny balíky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="901"/>
        <location filename="../mainwindow.cpp" line="2202"/>
        <source>Installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="581"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.cpp" line="2200"/>
        <source>Upgradable</source>
        <translation>Možné aktualizovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="586"/>
        <location filename="../mainwindow.ui" line="911"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2167"/>
        <location filename="../mainwindow.cpp" line="2204"/>
        <location filename="../mainwindow.cpp" line="2293"/>
        <source>Not installed</source>
        <translation>Nenainstalováno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Package Name</source>
        <translation>Název balíku</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="648"/>
        <location filename="../mainwindow.ui" line="970"/>
        <location filename="../mainwindow.ui" line="1243"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="680"/>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Total packages:</source>
        <translation>Balíků  celkem:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1032"/>
        <source>Installed:</source>
        <translation>Nainstalováno:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <location filename="../mainwindow.ui" line="740"/>
        <location filename="../mainwindow.ui" line="1062"/>
        <source>Upgradable:</source>
        <translation>Možné aktualizovat:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="1313"/>
        <source>Upgrade All</source>
        <translation>Aktualizovat všechno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1089"/>
        <source>Hide library and developer packages</source>
        <translation>Skrýt knihovny a vývojářské balíky</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="1111"/>
        <source>Refresh list</source>
        <translation>Obnovit seznam</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="919"/>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Zešednuté položky již byly nainstalovány.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <location filename="../mainwindow.ui" line="536"/>
        <location filename="../mainwindow.ui" line="856"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Balík je možné aktualizovat, ve vybraném repozitáři je dostupná novější verze programu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>Testovací repozitář</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Debian Backports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Flatpaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1159"/>
        <location filename="../mainwindow.ui" line="1163"/>
        <location filename="../mainwindow.cpp" line="2148"/>
        <source>All apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <location filename="../mainwindow.cpp" line="2153"/>
        <source>All runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <location filename="../mainwindow.cpp" line="2158"/>
        <source>All available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1178"/>
        <location filename="../mainwindow.cpp" line="2146"/>
        <location filename="../mainwindow.cpp" line="2288"/>
        <source>Installed apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1183"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <source>Installed runtimes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Short Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1238"/>
        <source>Full Package Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <source>Size</source>
        <translation>Velikost</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Total items </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1306"/>
        <source>Installed apps:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Advanced</source>
        <translation>Rozšířené</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1389"/>
        <source>Total installed size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <location filename="../mainwindow.ui" line="1410"/>
        <source>For all users</source>
        <translation>Pro všechny uživatele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1415"/>
        <source>For current user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1433"/>
        <source>Remote (repo):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1476"/>
        <location filename="../mainwindow.cpp" line="1975"/>
        <location filename="../mainwindow.cpp" line="2101"/>
        <source>Console Output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Enter</source>
        <translation>Zadat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1493"/>
        <source>Respond here, or just press Enter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1549"/>
        <source>Uninstall</source>
        <translation>Odinstalovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1556"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1572"/>
        <source>About this application</source>
        <translation>O této aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1575"/>
        <source>About...</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1582"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1630"/>
        <source>Display help </source>
        <translation>Zobrazit nápovědu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1640"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1656"/>
        <location filename="../mainwindow.cpp" line="1878"/>
        <location filename="../mainwindow.cpp" line="2282"/>
        <location filename="../mainwindow.cpp" line="2285"/>
        <source>Install</source>
        <translation>Instalovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1663"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1682"/>
        <source>Quit application</source>
        <translation>Ukončit aplikaci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1685"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1692"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>Uninstalling packages...</source>
        <translation>Odstraňování balíků...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Running post-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Refreshing sources...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="1946"/>
        <location filename="../mainwindow.cpp" line="1966"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Please wait...</source>
        <translation>Prosím vyčkejte...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version </source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source> in stable repo</source>
        <translation>v hlavním repozitáři</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Not available in stable repo</source>
        <translation>Není dostupné v hlavním repozitáři</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source>Latest version </source>
        <translation>Nejnovější verze</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2081"/>
        <source> already installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source> installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="880"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Chystáte se použít zdroj Debian Backports, který obsahuje softvérové balíky převzaté z budoucího vydání Debian-u (nazývaný taky &apos;testovací větev&apos;), přizpůsobené pro použití v stabilním Debian-u. Tyto balíky nemohou být otestovány tak rozsáhle jako balíky ze stabilní větve Debian-u a MX Linuxu a jsou poskytovány tak-jak-jsou, s rizikem ztráty kompatibility s jinými komponenty ze stabilní větve Debian-u. Používejte se vší opatrností!  </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="897"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="906"/>
        <source>Warning</source>
        <translation>Varování</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="910"/>
        <source>Do not show this message again</source>
        <translation>Znovu nezobrazovat tuto zprávu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <location filename="../mainwindow.cpp" line="1063"/>
        <location filename="../mainwindow.cpp" line="1179"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Není k dispozici internetové připojení, stažení seznamu balíků nebude možné</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="950"/>
        <source>Installing packages...</source>
        <translation>Instalace balíků...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="993"/>
        <source>Post-processing...</source>
        <translation>Dokončování...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1025"/>
        <source>Pre-processing for </source>
        <translation>Příprava pro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1038"/>
        <source>Installing </source>
        <translation>Instalace</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1045"/>
        <source>Post-processing for </source>
        <translation>Dokončování pro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1186"/>
        <source>Downloading package info...</source>
        <translation>Stahuji infrmace o balících...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1633"/>
        <source>Packages to be installed: </source>
        <translation>Balíky k instalaci:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1671"/>
        <source>Package info</source>
        <translation>Informace o balíku</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Done</source>
        <translation>Hotovo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1789"/>
        <location filename="../mainwindow.cpp" line="1802"/>
        <location filename="../mainwindow.cpp" line="1815"/>
        <location filename="../mainwindow.cpp" line="1941"/>
        <location filename="../mainwindow.cpp" line="1959"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <location filename="../mainwindow.cpp" line="2442"/>
        <location filename="../mainwindow.cpp" line="2469"/>
        <source>Processing finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1808"/>
        <location filename="../mainwindow.cpp" line="1818"/>
        <location filename="../mainwindow.cpp" line="2372"/>
        <location filename="../mainwindow.cpp" line="2448"/>
        <location filename="../mainwindow.cpp" line="2475"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1828"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1833"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1847"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Package Installer</source>
        <translation type="vanished">O programu MX Instalátor softvéru </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1829"/>
        <source>Version: </source>
        <translation>Verze:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1830"/>
        <source>Package Installer for MX Linux</source>
        <translation>Program pro instalaci dodatečného softvéru pro MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1832"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Vlastnická práva (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licence</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Zavřít</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1876"/>
        <source>Reinstall</source>
        <translation>Přeinstalovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1946"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>Success</source>
        <translation>Úspěch!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1966"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak not installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2057"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>Flatpak was not installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2089"/>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Flathub remote could not be added</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>Needs re-login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2097"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2280"/>
        <source>Upgrade</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2402"/>
        <source>Quit?</source>
        <translation>Ukončit?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2403"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Pro všechny uživatele</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Úspěch!</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Unable to get exclusive lock</source>
        <translation>Nebylo možné zamknout soubor</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Jiná aplikace pro správu softvéru (napr. Synaptic nebo apt-get) již běží.
Prosím nejdřiv ji ukončete</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="89"/>
        <source>You must run this program as root.</source>
        <translation>Tuto aplikaci musíte spustit jako root.</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Zavřít</translation>
    </message>
</context>
</TS>
